@@ -20,21 +20,20 @@ density_estimation<-function(X=X,nbclustmax=10,verbose=FALSE,detailed=FALSE,max=
   if(detailed){
     detailsmat=list() 
   }
-  mclust==T
   if(mclust==F){#si on veut utiliser mixmod
-#     for (i in 1:p){
-#       vect=X[!is.na(X[,i]),i]#donnees observees seulement
-#       res=mixmodCluster(data=vect,criterion="BIC",nbCluster=c(1:nbclustmax),strategy=mixmodStrategy(nbTryInInit=nbini))["bestResult"]
-#       if(verbose){print(res)}
-#       nbclust[i]=res[1]
-#       BIC_vect[i]=res[3]
-#       if(detailed){
-#         prop=res[6][1]#proportions
-#         meansvect=c(res[6][2])#means
-#         varvect=unlist(res[6][3])#variances
-#         detailsmat[[i]]=cbind(prop,meansvect,varvect,i)
-#       }
-#     }
+    for (i in 1:p){
+      vect=X[!is.na(X[,i]),i]#donnees observees seulement
+      res=mixmodCluster(data=vect,criterion="BIC",nbCluster=c(1:nbclustmax),strategy=mixmodStrategy(nbTryInInit=nbini))["bestResult"]
+      if(verbose){print(res)}
+      nbclust[i]=res[1]
+      BIC_vect[i]=res[3]
+      if(detailed){
+        prop=res[6][1]#proportions
+        meansvect=c(res[6][2])#means
+        varvect=unlist(res[6][3])#variances
+        detailsmat[[i]]=cbind(prop,meansvect,varvect,i)
+      }
+    }
   }else{#on utilise mclust
     options(warn=-1)
     for (i in 1:p){
